#Notes from TMDL Stafff Report Section 4.7.1
# Only fish fillet data were used in the human and eagle trophic level food group analysis. Humans typically consume fish fillets, while wildlife species, including eagles, eat whole fish. However, all the data for large fish typically consumed by eagles and other large wildlife species are from fillet samples, making it necessary to use fillet information for these species.24 Whole fish data were used for the smaller wildlife species food groups.

#Team Note: Above rationale could be implemented by filtering for 'Fillet' for human evaluation only.... 

TLG_CompositeWeighted_AvgHg <- function(dataframe, ...){
  ## Calculate Avg [Hg] (weighted by composite size) for each TLG by Subarea
  
  dataframe <- dataframe %>% 
    ungroup # ungroup dataframe as precaution so filtering works as expected

  # grouping_var <- quo(Subarea) - to test function line-wise
  grouping_var <- enquos(...)
  
  #TL4 Fish (150-500 mm)
  TL4_150_500 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL4' & TLAvgLength >=150 & TLAvgLength <=500 ~ 'TL4 Fish (150-500 mm)',
                            T ~ NA_character_)) %>% 
    filter(!is.na(TLG),
           TissueName == 'Fillet') %>% 
    group_by(!!! grouping_var) %>% 
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              TLG                 = 'TL4 Fish (150-500 mm)',
              .groups='drop')
  TL4_150_500.human <- TL4_150_500 %>% 
    mutate(Predator = 'Human',
           TLGtarget = 0.24)
  TL4_150_500.eagle <- TL4_150_500 %>% 
    mutate(Predator = 'Bald Eagle',
           TLGtarget = 0.31)
  
  TL4_150_500 <- rbind(TL4_150_500.human, TL4_150_500.eagle)
  
  
  #TL4 Fish (150-350 mm)
  TL4_150_350 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL4' & TLAvgLength >=150 & TLAvgLength <=350 ~ 'TL4 Fish (150-350 mm)',
                            T ~ NA_character_)) %>% 
    filter(!is.na(TLG)) %>% 
    group_by(!!! grouping_var) %>% 
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              TLG                 = 'TL4 Fish (150-350 mm)',
              .groups='drop')
  TL4_150_350.osprey <- TL4_150_350 %>% 
    mutate(Predator = 'Osprey',
           TLGtarget = 0.26)
  TL4_150_350.otter <- TL4_150_350 %>% 
    mutate(Predator = 'River Otter',
           TLGtarget = 0.36)
  TL4_150_350 <- rbind(TL4_150_350.osprey, TL4_150_350.otter)
  
  
  #TL3 Fish (150-500 mm)
  TL3_150_500 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength >=150 & TLAvgLength <=500 ~ 'TL3 Fish (150-500 mm)',
                            T ~ NA_character_)) %>% 
    filter(!is.na(TLG),
           TissueName == 'Fillet') %>% 
    group_by(!!! grouping_var) %>% 
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              TLG                 = 'TL3 Fish (150-500 mm)',
              .groups='drop')
  TL3_150_500.human <- TL3_150_500 %>% 
    mutate(Predator = 'Human',
           TLGtarget = 0.08)
  TL3_150_500.eagle <- TL3_150_500 %>% 
    mutate(Predator = 'Bald Eagle',
           TLGtarget = 0.11)
  TL3_150_500 <- rbind(TL3_150_500.human, TL3_150_500.eagle)
  
  
  
  #TL3 Fish (150-350 mm)
  TL3_150_350 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength >=150 & TLAvgLength <=350 ~ 'TL3 Fish (150-350 mm)',
                            T ~ NA_character_)) %>% 
    filter(!is.na(TLG)) %>% 
    group_by(!!! grouping_var) %>% 
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              TLG                 = 'TL3 Fish (150-350 mm)',
              .groups='drop')
  TL3_150_350.grebe <- TL3_150_350 %>% 
    mutate(Predator = 'Western grebe',
           TLGtarget = 0.08)
  TL3_150_350.merganser <- TL3_150_350 %>% 
    mutate(Predator = 'Common merganser & Osprey',
           TLGtarget = 0.09)
  TL3_150_350 <- rbind(TL3_150_350.grebe, TL3_150_350.merganser)
  
  
  #TL3 Fish (50 - <150 mm)
  TL3_50_150 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength >=50 & TLAvgLength <150 ~ 'TL3 Fish (50 - <150 mm)',
                            T ~ NA_character_)) %>% 
    filter(!is.na(TLG)) %>% 
    group_by(!!! grouping_var) %>% 
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              TLG                 = 'TL3 Fish (50 - <150 mm)',
              .groups='drop')
  TL3_50_150.fisher <- TL3_50_150 %>% 
    mutate(Predator = 'Kingfisher ',
           TLGtarget = 0.05)
  TL3_50_150.mink <- TL3_50_150 %>% 
    mutate(Predator = 'Mink',
           TLGtarget = 0.08)
  TL3_50_150.otter <- TL3_50_150 %>% 
    mutate(Predator = 'River otter',
           TLGtarget = 0.04)
  TL3_50_150.cormorant <- TL3_50_150 %>% 
    mutate(Predator = 'Double-crested cormorant',
           TLGtarget = 0.09)
  TL3_50_150 <- rbind(TL3_50_150.fisher, TL3_50_150.mink, TL3_50_150.otter, TL3_50_150.cormorant)
  
  
  #TL3 Fish (<50 mm)
  TL3_50 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength <50 ~ 'TL3 Fish (<50 mm)',
                            T ~ NA_character_)) %>% 
    filter(!is.na(TLG)) %>% 
    group_by(!!! grouping_var) %>% 
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              TLG                 = 'TL3 Fish (<50 mm)',
              .groups='drop')
  TL3_50.tern <- TL3_50 %>% 
    mutate(Predator = 'California least tern',
           TLGtarget = 0.03)
  TL3_50.plover <- TL3_50 %>% 
    mutate(Predator = 'Western snowy plover',
           TLGtarget = 0.1)
  TL3_50 <- rbind(TL3_50.tern, TL3_50.plover)
  
  
  
  results <- rbind(TL4_150_500, TL4_150_350, TL3_150_500, TL3_150_350, TL3_50_150, TL3_50) %>% 
    select(TLG, Predator, TLGtarget, everything())
  
  return(results)
}
