#Notes from TMDL Stafff Report Section 4.7.1
# Only fish fillet data were used in the human and eagle trophic level food group analysis. Humans typically consume fish fillets, while wildlife species, including eagles, eat whole fish. However, all the data for large fish typically consumed by eagles and other large wildlife species are from fillet samples, making it necessary to use fillet information for these species.24 Whole fish data were used for the smaller wildlife species food groups.

#The below code is used to test above rationale by filtering for 'Fillet' or  'Whole Body' below, to see if this rationale severely limits the number of Subareas included in the TLG analysis.

TLG_CompositeWeighted_AvgHg_TissueOptns <- function(dataframe, ...){
  ## Calculate Avg [Hg] (weighted by composite size) for each TLG by Subarea
  
  dataframe <- dataframe %>% 
    ungroup # ungroup dataframe as precaution so filtering works as expected

  # grouping_var <- quo(Subarea) - to test function line-wise
  grouping_var <- enquos(...)
  
  #TL4 Fish (150-500 mm)
  tl4_500 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL4' & TLAvgLength >=150 & TLAvgLength <=500 ~ 'TL4 Fish (150-500 mm)',
                           T ~ NA_character_)) %>%
    filter(!is.na(TLG))
  
  both <- tl4_500 %>% 
    group_by(TLG, !!! grouping_var) %>%
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              Tissue               = 'Fillet & Whole Body',
              .groups='drop')
  
  alt <- tl4_500 %>%
    filter(TissueName == 'Fillet')
  
  if(nrow(alt) > 0){
    alt <- alt %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
                CompositeSamples     = n(),
                CompositeTotalFish   = sum(NumberFishPerComp),
                Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
                Tissue               = TissueName[1],
                .groups='drop')
  } else{
    alt <- both %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = NA,
                CompositeSamples     = NA,
                CompositeTotalFish   = NA,
                Years                = NA,
                Tissue               = 'Fillet',
                .groups='drop')
  }
  
  tl4_500_results <- rbind(both, alt)
  
  
  
  #TL4 Fish (150-350 mm)
  tl4_350 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL4' & TLAvgLength >=150 & TLAvgLength <=350 ~ 'TL4 Fish (150-350 mm)',
                           T ~ NA_character_)) %>%
    filter(!is.na(TLG))
  
  both <- tl4_350 %>% 
    group_by(TLG, !!! grouping_var) %>%
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              Tissue               = 'Fillet & Whole Body',
              .groups='drop')
  
  alt <- tl4_350 %>%
    filter(TissueName == 'Whole Body')
  
  if(nrow(alt) > 0){
    alt <- alt %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
                CompositeSamples     = n(),
                CompositeTotalFish   = sum(NumberFishPerComp),
                Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
                Tissue               = TissueName[1],
                .groups='drop')
  } else{
    alt <- both %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = NA,
                CompositeSamples     = NA,
                CompositeTotalFish   = NA,
                Years                = NA,
                Tissue               = 'Whole Body',
                .groups='drop')
  }
  
  tl4_350_results <- rbind(both, alt)
  
  
  
  #TL3 Fish (150-500 mm)
  tl3_500 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength >=150 & TLAvgLength <=500 ~ 'TL3 Fish (150-500 mm)',
                           T ~ NA_character_)) %>%
    filter(!is.na(TLG))
  
  both <- tl3_500 %>% 
    group_by(TLG, !!! grouping_var) %>%
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              Tissue               = 'Fillet & Whole Body',
              .groups='drop')
  
  alt <- tl3_500 %>%
    filter(TissueName == 'Fillet')
  
  if(nrow(alt) > 0){
    alt <- alt %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
                CompositeSamples     = n(),
                CompositeTotalFish   = sum(NumberFishPerComp),
                Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
                Tissue               = TissueName[1],
                .groups='drop')
  } else{
    alt <- both %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = NA,
                CompositeSamples     = NA,
                CompositeTotalFish   = NA,
                Years                = NA,
                Tissue               = 'Fillet',
                .groups='drop')
  }
  
  tl3_500_results <- rbind(both, alt)
  
  
  
  #TL3 Fish (150-350 mm)
  tl3_350 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength >=150 & TLAvgLength <=350 ~ 'TL3 Fish (150-350 mm)',
                           T ~ NA_character_)) %>%
    filter(!is.na(TLG))
  
  both <- tl3_350 %>% 
    group_by(TLG, !!! grouping_var) %>%
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              Tissue               = 'Fillet & Whole Body',
              .groups='drop')
  
  alt <- tl3_350 %>%
    filter(TissueName == 'Whole Body')
  
  if(nrow(alt) > 0){
    alt <- alt %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
                CompositeSamples     = n(),
                CompositeTotalFish   = sum(NumberFishPerComp),
                Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
                Tissue               = TissueName[1],
                .groups='drop')
  } else{
    alt <- both %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = NA,
                CompositeSamples     = NA,
                CompositeTotalFish   = NA,
                Years                = NA,
                Tissue               = 'Whole Body',
                .groups='drop')
  }
  
  tl3_350_results <- rbind(both, alt)
  
  
  
  #TL3 Fish (50 - <150 mm)
  tl3_150 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength >=50 & TLAvgLength < 150 ~ 'TL3 Fish (50 - <150 mm)',
                           T ~ NA_character_)) %>%
    filter(!is.na(TLG))
  
  both <- tl3_150 %>% 
    group_by(TLG, !!! grouping_var) %>%
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              Tissue               = 'Fillet & Whole Body',
              .groups='drop')
  
  alt <- tl3_150 %>%
    filter(TissueName == 'Whole Body')
  
  if(nrow(alt) > 0){
    alt <- alt %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
                CompositeSamples     = n(),
                CompositeTotalFish   = sum(NumberFishPerComp),
                Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
                Tissue               = TissueName[1],
                .groups='drop')
  } else{
    alt <- both %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = NA,
                CompositeSamples     = NA,
                CompositeTotalFish   = NA,
                Years                = NA,
                Tissue               = 'Whole Body',
                .groups='drop')
  }
  
  tl3_150_results <- rbind(both, alt)
  
  
  
  #TL3 Fish (<50 mm)
  tl3_50 <- dataframe %>% 
    mutate(TLG = case_when(TrophicLevel =='TL3' & TLAvgLength <50 ~ 'TL3 Fish (<50 mm)',
                           T ~ NA_character_)) %>%
    filter(!is.na(TLG))
  
  both <- tl3_50 %>% 
    group_by(TLG, !!! grouping_var) %>%
    summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
              CompositeSamples     = n(),
              CompositeTotalFish   = sum(NumberFishPerComp),
              Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
              Tissue               = 'Fillet & Whole Body',
              .groups='drop')
  
  alt <- tl3_50 %>%
    filter(TissueName == 'Whole Body')
  
  if(nrow(alt) > 0){
    alt <- alt %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = weighted.mean(Result, NumberFishPerComp),
                CompositeSamples     = n(),
                CompositeTotalFish   = sum(NumberFishPerComp),
                Years                = paste(sort(unique(year(SampleDate))), collapse=', '),
                Tissue               = TissueName[1],
                .groups='drop')
  } else{
    alt <- both %>% 
      group_by(TLG, !!! grouping_var) %>%
      summarise(CompositeWeightedAvg = NA,
                CompositeSamples     = NA,
                CompositeTotalFish   = NA,
                Years                = NA,
                Tissue               = 'Whole Body',
                .groups='drop')
  }
  
  tl3_50_results <- rbind(both, alt)
  
  
  # Bind results
  results <- rbind(tl4_500_results, tl4_350_results, tl3_500_results, tl3_350_results, tl3_150_results, tl3_50_results) %>% 
    select(TLG, Tissue, everything())
  
  return(results)
}
